pub unsafe trait CLSContextProvider {
// Provided method
unsafe fn updateDescendantsOfContext_completion(
&self,
context: &CLSContext,
completion: &DynBlock<dyn Fn(*mut NSError)>,
)
where Self: Sized + Message { ... }
}Available on crate feature
CLSContextProvider only.Expand description
The CLSContext provider protocol.
The app extension that provides CLSContexts should adopt this protocol.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn updateDescendantsOfContext_completion(
&self,
context: &CLSContext,
completion: &DynBlock<dyn Fn(*mut NSError)>,
)
Available on crate features block2 and CLSContext and CLSObject only.
unsafe fn updateDescendantsOfContext_completion( &self, context: &CLSContext, completion: &DynBlock<dyn Fn(*mut NSError)>, )
block2 and CLSContext and CLSObject only.This method asks the app extension to update CLSContexts that are descendants of a given context.
Parameter context: A CLSContext whose descendants are to be updated
Parameter completion: A completion block the extension should call with an optional error to indicate success or failure.
The extension may choose to modify, delete, or create some or all descendants of the given context. The host app may call this method as the user selects a context.